@@ -2,9 +2,12 @@
 #[macro_use]
 extern crate lalrpop_util;
 
-lalrpop_mod!(#[allow(clippy::all)] grammar);
+lalrpop_mod!(
+    #[allow(clippy::all)]
+    grammar
+);
 
 pub mod ast;
 
 pub use grammar::*;
-pub use lalrpop_util::*;
\ No newline at end of file
+pub use lalrpop_util::*;
